//  This file is part of the computer game Kartofel.
//  Copyright (C) 2008 Pawel Aleksander Fedorynski <pfedor@fuw.edu.pl>
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#include "lines.h"
#include "util.h"

namespace kartofel {

void Lines::Clear()
{
  line_segments_.clear();
}

void Lines::SetStart(int x, int y)
{
  current_x_ = x;
  current_y_ = y;
}

void Lines::LineTo(int target_x, int target_y)
{
  line_segments_.push_back(LineSegment(current_x_, current_y_,
                                       target_x, target_y));
  current_x_ = target_x;
  current_y_ = target_y;
}

bool Lines::WouldIntersect(int from_x, int from_y, int to_x, int to_y,
                           int* intersection_x, int* intersection_y,
                           bool starting) const
{
  LineSegment ls(from_x, from_y, to_x, to_y);
  int min_distsq;
  bool found = false;
  int end = starting ? line_segments_.size() : line_segments_.size() - 1;
  for (int i = 0; i < end; i++) {
    int ix, iy;
    if (LineSegmentsIntersect(ls, line_segments_[i], &ix, &iy)) {
      //cout << "INTERSECTION\n";
      int distsq = (ix - from_x) * (ix - from_x) +
        (iy - from_y) * (iy - from_y);
      if (!found || distsq < min_distsq) {
        found = true;
        min_distsq = distsq;
        *intersection_x = ix;
        *intersection_y = iy;
      }
    }
  }
  return found;
}

void Lines::Reset() const
{
  current_line_segment_ = 0;
}

bool Lines::GetNext(int* x1, int* y1, int* x2, int* y2) const
{
  if (current_line_segment_ == line_segments_.size()) {
    return false;
  }
  *x1 = line_segments_[current_line_segment_].x1;
  *y1 = line_segments_[current_line_segment_].y1;
  *x2 = line_segments_[current_line_segment_].x2;
  *y2 = line_segments_[current_line_segment_].y2;
  current_line_segment_++;
  return true;
}

}  // namespace kartofel
