//  This file is part of the computer game Kartofel.
//  Copyright (C) 2008 Pawel Aleksander Fedorynski <pfedor@fuw.edu.pl>
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#ifndef KARTOFEL_LINES_H
#define KARTOFEL_LINES_H

#include <vector>

#include "util.h"

namespace kartofel {

using std::vector;

class Lines {
public:
  void Clear();
  void SetStart(int x, int y);
  // Returns true if there's an intersection.
  bool WouldIntersect(int from_x, int from_y, int to_x, int to_y,
                      int* intersection_x, int* intersection_y,
                      bool starting) const;
  void LineTo(int target_x, int target_y);

  // For iterating.
  void Reset() const;
  bool GetNext(int* x1, int* y1, int* x2, int* y2) const;

private:
  // The simplest implementation imaginable.
  vector<LineSegment> line_segments_;
  int current_x_;
  int current_y_;

  // For iterating.
  mutable int current_line_segment_;
};

}  // namespace kartofel

#endif  // KARTOFEL_LINES_H
