//  This file is part of the computer game Kartofel.
//  Copyright (C) 2008 Pawel Aleksander Fedorynski <pfedor@fuw.edu.pl>
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#include "submit_game.h"

#include <curl/curl.h>
#include <iostream>
#include <string>

#include "config.h"

namespace kartofel {

using namespace std;

bool SubmitGame(const string& name, int score,
                const string& version, const string& game)
{
  CURL* curl = curl_easy_init();
  if (!curl) {
    cerr << "curl_easy_init() failed.\n";
    return false;
  }
  bool retv = true;
  curl_httppost* post = NULL;
  curl_httppost* last = NULL;
  CURLcode rc;
  CURLFORMcode rcf;
  rcf = curl_formadd(&post, &last,
                     CURLFORM_COPYNAME, "name",
                     CURLFORM_COPYCONTENTS, name.c_str(),
                     CURLFORM_END);
  if (rcf != 0) {
    cerr << "curl_formadd() failed for \"name\".\n";
    retv = false;
    goto done;
  }
  char score_buf[100];
  snprintf(score_buf, sizeof(score_buf), "%d", score);
  rcf = curl_formadd(&post, &last,
                     CURLFORM_COPYNAME, "score",
                     CURLFORM_COPYCONTENTS, score_buf,
               	     CURLFORM_END);
  if (rcf != 0) {
    cerr << "curl_formadd() failed for \"score\".\n";
    retv = false;
    goto done;
  }
  rcf = curl_formadd(&post, &last,
                     CURLFORM_COPYNAME, "version",
                     CURLFORM_COPYCONTENTS, version.c_str(),
                     CURLFORM_END);
  if (rcf != 0) {
    cerr << "curl_formadd() failed for \"version\".\n";
    retv = false;
    goto done;
  }
  rcf = curl_formadd(&post, &last,
                     CURLFORM_COPYNAME, "game",
                     CURLFORM_COPYCONTENTS, game.data(),
                     CURLFORM_CONTENTSLENGTH, game.size(),
                     //CURLFORM_FILECONTENT, game.c_str(),
                     CURLFORM_END);
  if (rcf != 0) {
    cerr << "curl_formadd() failed for \"game\".\n";
    retv = false;
    goto done;
  }
  rc = curl_easy_setopt(curl, CURLOPT_URL, SCORE_SUBMISSION_URL);
  if (rc != 0) {
    cerr << curl_easy_strerror(rc) << endl;
    retv = false;
    goto done;
  }
  rc = curl_easy_setopt(curl, CURLOPT_NOSIGNAL, 1);
  if (rc != 0) {
    cerr << curl_easy_strerror(rc) << endl;
    retv = false;
    goto done;
  }
  rc = curl_easy_setopt(curl, CURLOPT_HTTPPOST, post);
  if (rc != 0) {
    cerr << curl_easy_strerror(rc) << endl;
    retv = false;
    goto done;
  }
  rc = curl_easy_perform(curl);
  if (rc != 0) {
    cerr << curl_easy_strerror(rc) << endl;
    retv = false;
    goto done;
  }
done:
  curl_formfree(post);
  curl_easy_cleanup(curl);
  return retv;
}

}  // namespace kartofel

/*
int main()
{
  CURLcode rc = curl_global_init(CURL_GLOBAL_ALL);
  if (rc != 0) {
    cerr << curl_easy_strerror(rc) << endl;
    exit(1);
  }
  bool ok = SubmitGame("John Rambo", 65536,
                       "1.0", "games/1229748570");
  cerr << (ok ? "success" : "failure") << endl;
  curl_global_cleanup();
}
*/
