//  This file is part of the computer game Kartofel.
//  Copyright (C) 2009 Pawel Aleksander Fedorynski <pfedor@fuw.edu.pl>
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#include <cassert>

#include "trig_table.h"
#include "util.h"

using namespace std;

namespace kartofel {

extern long long trig_table_sin[];
extern long long trig_table_cos[];

int RTimesSinPhi(int r, int phi)
{
  assert(r >= 0 && r < 10000);
  long long s = trig_table_sin[phi];
  long long correction = TRIG_TABLE_SCALE / 2;
  if (s < 0) {
    correction = -correction;
  }
  return (s * r + correction) / TRIG_TABLE_SCALE;
}

int RTimesCosPhi(int r, int phi)
{
  assert(r >= 0 && r < 10000);
  long long c = trig_table_cos[phi];
  long long correction = TRIG_TABLE_SCALE / 2;
  if (c < 0) {
    correction = -correction;
  }
  return (c * r + correction) / TRIG_TABLE_SCALE;
}

}  // namespace kartofel
