//  This file is part of the computer game Kartofel.
//  Copyright (C) 2009 Pawel Aleksander Fedorynski <pfedor@fuw.edu.pl>
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#ifndef KARTOFEL_TRIG_TABLE_H
#define KARTOFEL_TRIG_TABLE_H

// The reason for using precomputed trigonometric functions is to avoid
// floating point indeterminism to make the score verification code
// work correctly regardless of rounding etc.  The only place where any
// floating point numbers are used is in util.cc to calculate the exact point
// of an intersection between two line segments and between a line segment and
// a circle.  (The fact that they do intersect somewhere is determined
// using only integer operations.)  This can't impact anything, since as
// soon as there's an intersection we either crash or land on the next dot,
// in either case the position is reset.

namespace kartofel {

enum {
  // This times 10000 will still fit in a long long.
  TRIG_TABLE_SCALE = 100000000000000LL
};

// Like DoubleToInt(r * sin(2 * PI * phi / FULL_ANGLE)) but the result
// doesn't depend on the phase of the moon.
int RTimesSinPhi(int r, int phi);

// Like DoubleToInt(r * cos(2 * PI * phi / FULL_ANGLE)) but the result
// doesn't depend on the phase of the moon.
int RTimesCosPhi(int r, int phi);

}  // namespace kartofel

#endif  // KARTOFEL_TRIG_TABLE_H
